Index: trunk/psModules/test/objects/tap_pmSource.c
===================================================================
--- trunk/psModules/test/objects/tap_pmSource.c	(revision 21223)
+++ trunk/psModules/test/objects/tap_pmSource.c	(revision 21471)
@@ -48,5 +48,5 @@
     readout->image = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
     readout->mask = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_U8);
-    readout->weight = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
+    readout->variance = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
     for (psS32 i = 0 ; i < NUM_BIAS_DATA ; i++) {
         psImage *tmpImage = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
@@ -77,5 +77,5 @@
         ok(src->peak == NULL, "pmSourceAlloc() pmSource->peak correctly");
         ok(src->pixels == NULL, "pmSourceAlloc() pmSource->pixels correctly");
-        ok(src->weight == NULL, "pmSourceAlloc() pmSource->weight correctly");
+        ok(src->variance == NULL, "pmSourceAlloc() pmSource->variance correctly");
         ok(src->maskObj == NULL, "pmSourceAlloc() pmSource->maskObj correctly");
         ok(src->maskView == NULL, "pmSourceAlloc() pmSource->maskView correctly");
@@ -169,5 +169,5 @@
 
         src->pixels = psImageAlloc(2, 4, PS_TYPE_F32);
-        src->weight = psImageAlloc(6, 8, PS_TYPE_F32);
+        src->variance = psImageAlloc(6, 8, PS_TYPE_F32);
         src->maskView  = psImageAlloc(10, 12, PS_TYPE_U8);
         pmSource *dst = pmSourceCopy(src);
@@ -207,7 +207,7 @@
         ok(dst->pixels->numCols == src->pixels->numCols && dst->pixels->numRows == src->pixels->numRows, 
            "pmSourceCopy() generated correct size pmSource->pixels");
-        ok(dst->weight != NULL, "pmSourceCopy() allocated a new pmSource->weight");
-        ok(dst->weight->numCols == src->weight->numCols && dst->weight->numRows == src->weight->numRows, 
-           "pmSourceCopy() generated correct size pmSource->weight");
+        ok(dst->variance != NULL, "pmSourceCopy() allocated a new pmSource->variance");
+        ok(dst->variance->numCols == src->variance->numCols && dst->variance->numRows == src->variance->numRows, 
+           "pmSourceCopy() generated correct size pmSource->variance");
         ok(dst->maskView != NULL, "pmSourceCopy() allocated a new pmSource->maskView");
         ok(dst->maskView->numCols == src->maskView->numCols && dst->maskView->numRows == src->maskView->numRows, 
@@ -290,11 +290,11 @@
         int expectedNumCols = 1 + (TEST_NUM_COLS/2);
         int expectedNumRows = 1 + (TEST_NUM_COLS/2);
         // XX: We only verify the size of the pixels, weight, maskView, and maskObj
         // images.  A better test would verify that the actual data is set correctly.
         // We don't do that here since it basically duplicated psLib function tests.
         ok(src->pixels->numCols == expectedNumCols && src->pixels->numRows == expectedNumRows, 
                "pmSourceDefinePixels() set the size of pmSource->pixels correctly");
-        ok(src->weight->numCols == expectedNumCols && src->weight->numRows == expectedNumRows, 
-               "pmSourceDefinePixels() set the size of pmSource->weight correctly");
+        ok(src->variance->numCols == expectedNumCols && src->variance->numRows == expectedNumRows, 
+               "pmSourceDefinePixels() set the size of pmSource->variance correctly");
         ok(src->maskView->numCols == expectedNumCols && src->maskView->numRows == expectedNumRows, 
                "pmSourceDefinePixels() set the size of pmSource->maskView correctly");
@@ -396,11 +396,11 @@
         int expectedNumCols = 1 + (TEST_NUM_COLS/2);
         int expectedNumRows = 1 + (TEST_NUM_COLS/2);
         // XX: We only verify the size of the pixels, weight, maskView, and maskObj
         // images.  A better test would verify that the actual data is set correctly.
         // We don't do that here since it basically duplicated psLib function tests.
         ok(src->pixels->numCols == expectedNumCols && src->pixels->numRows == expectedNumRows, 
                "pmSourceRedefinePixels() set the size of pmSource->pixels correctly");
-        ok(src->weight->numCols == expectedNumCols && src->weight->numRows == expectedNumRows, 
-               "pmSourceRedefinePixels() set the size of pmSource->weight correctly");
+        ok(src->variance->numCols == expectedNumCols && src->variance->numRows == expectedNumRows, 
+               "pmSourceRedefinePixels() set the size of pmSource->variance correctly");
         ok(src->maskView->numCols == expectedNumCols && src->maskView->numRows == expectedNumRows, 
                "pmSourceRedefinePixels() set the size of pmSource->maskView correctly");
@@ -584,5 +584,5 @@
     // We only test with a single Gaussian model, with no residuals or masks.
     // For completeness, additional tests should be added.
-        // We should also set mode &= PM_MODEL_OP_NOISE to test that the src->weights are added.
+        // We should also set mode &= PM_MODEL_OP_NOISE to test that the src->variances are added.
     {
         psMemId id = psMemGetId();
@@ -632,5 +632,5 @@
     // call pmSourceOp() with acceptable parameters
     // Test source->modelFlux
-        // We should also set mode &= PM_MODEL_OP_NOISE to test that the src->weights are added.
+        // We should also set mode &= PM_MODEL_OP_NOISE to test that the src->variances are added.
     {
         psMemId id = psMemGetId();
@@ -290,11 +290,11 @@
         int expectedNumCols = 1 + (TEST_NUM_COLS/2);
         int expectedNumRows = 1 + (TEST_NUM_COLS/2);
-        // XX: We only verify the size of the pixels, weight, maskView, and maskObj
+        // XX: We only verify the size of the pixels, variance, maskView, and maskObj
         // images.  A better test would verify that the actual data is set correctly.
         // We don't do that here since it basically duplicated psLib function tests.
@@ -396,11 +396,11 @@
         int expectedNumCols = 1 + (TEST_NUM_COLS/2);
         int expectedNumRows = 1 + (TEST_NUM_COLS/2);
-        // XX: We only verify the size of the pixels, weight, maskView, and maskObj
+        // XX: We only verify the size of the pixels, variance, maskView, and maskObj
         // images.  A better test would verify that the actual data is set correctly.
         // We don't do that here since it basically duplicated psLib function tests.
